==> streams-node-from-circular-array-0.0.1.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Create a readable stream from an array-like object which repeatedly iterates over a provided value's elements.
*
* @module @stdlib/streams/node/from-circular-array
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* function log( chunk ) {
*    console.log( chunk.toString() );
* }
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'iter': arr.length * 2
* };
*
* var stream = circularArrayStream( arr, opts );
*
* stream.pipe( inspectStream( log ) );
*
* @example
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'sep': ',',
*     'objectMode': false,
*     'encoding': 'utf8',
*     'highWaterMark': 64
* };
*
* var createStream = circularArrayStream.factory( opts );
*
* // Create 10 identically configured streams...
* var streams = [];
* for ( i = 0; i < 10; i++ ) {
*     streams.push( createStream( arr ) );
* }
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* function log( v ) {
*    console.log( v );
* }
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'iter': arr.length * 2
* };
*
* var stream = circularArrayStream.objectMode( arr, opts );
*
* stream.pipe( inspectStream.objectMode( log ) );
*/


// MODULES //

var setReadOnly = require( '@stdlib/utils-define-nonenumerable-read-only-property' );
var stream = require( './main.js' );
var objectMode = require( './object_mode.js' );
var factory = require( './factory.js' );


// MAIN //

setReadOnly( stream, 'objectMode', objectMode );
setReadOnly( stream, 'factory', factory );


// EXPORTS //

module.exports = stream;

==> streams-node-from-circular-array-0.0.3.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Create a readable stream from an array-like object which repeatedly iterates over a provided value's elements.
*
* @module @stdlib/streams-node-from-circular-array
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* function log( chunk ) {
*    console.log( chunk.toString() );
* }
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'iter': arr.length * 2
* };
*
* var stream = circularArrayStream( arr, opts );
*
* stream.pipe( inspectStream( log ) );
*
* @example
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'sep': ',',
*     'objectMode': false,
*     'encoding': 'utf8',
*     'highWaterMark': 64
* };
*
* var createStream = circularArrayStream.factory( opts );
*
* // Create 10 identically configured streams...
* var streams = [];
* for ( i = 0; i < 10; i++ ) {
*     streams.push( createStream( arr ) );
* }
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var Float64Array = require( '@stdlib/array-float64' );
* var randu = require( '@stdlib/random-base-randu' );
* var circularArrayStream = require( '@stdlib/streams-node-from-circular-array' );
*
* function log( v ) {
*    console.log( v );
* }
*
* var arr = new Float64Array( 10 );
* var i;
* for ( i = 0; i < arr.length; i++ ) {
*     arr[ i ] = randu();
* }
*
* var opts = {
*     'iter': arr.length * 2
* };
*
* var stream = circularArrayStream.objectMode( arr, opts );
*
* stream.pipe( inspectStream.objectMode( log ) );
*/


// MODULES //

var setReadOnly = require( '@stdlib/utils-define-nonenumerable-read-only-property' );
var stream = require( './main.js' );
var objectMode = require( './object_mode.js' );
var factory = require( './factory.js' );


// MAIN //

setReadOnly( stream, 'objectMode', objectMode );
setReadOnly( stream, 'factory', factory );


// EXPORTS //

module.exports = stream;
